TypeInfo

Enum TypeInfo 

pub enum TypeInfo {
    FixedLen(FixedLenType),
    VarLenSized(VarLenContext),
    VarLenSizedPrecision {
        ty: VarLenType,
        size: usize,
        precision: u8,
        scale: u8,
    },
    Xml {
        schema: Option<Arc<XmlSchema>>,
        size: usize,
    },
    Udt(UdtInfo),
}
Describes a type of a column.

Variants



FixedLen(FixedLenType)

A fixed-length type, whose size is fully determined by the type itself.



VarLenSized(VarLenContext)

A variable-length type with an explicit size (and optional collation).



VarLenSizedPrecision

A variable-length type carrying a precision and scale, such as decimal and numeric.

Fields

ty: VarLenType

The underlying variable-length type.

size: usize

The reserved size of the column in bytes.

precision: u8

The total number of digits.

scale: u8

The number of digits to the right of the decimal point.



Xml

The xml type, with an optional associated schema.

Fields

schema: Option<Arc<XmlSchema>>

The XML schema associated with the column, if any.

size: usize

The reserved size of the column in bytes.



Udt(UdtInfo)

A CLR user-defined type (UDT), MS-TDS 2.2.5.5.4.