pub enum Error {
Show 13 variants
Io {
kind: IoErrorKind,
message: String,
},
Protocol(Cow<'static, str>),
Encoding(Cow<'static, str>),
Conversion(Cow<'static, str>),
Utf8,
Utf16,
ParseInt(ParseIntError),
Server(TokenError),
Tls(String),
Gssapi(String),
SspiRs(String),
Routing {
host: String,
port: u16,
},
BulkInput(Cow<'static, str>),
}Expand description
A unified error enum that contains several errors that might occurr during the lifecycle of this driver
Variants
Io
An error occurred when performing I/O to the server.
Fields
kind: IoErrorKindA list specifying general categories of I/O error.
Protocol(Cow<'static, str>)
An error happened during the request or response parsing.
Encoding(Cow<'static, str>)
Server responded with encoding not supported.
Conversion(Cow<'static, str>)
Conversion failure from one type to another.
Utf8
Tried to convert data to UTF-8 that was not valid.
Utf16
Tried to convert data to UTF-16 that was not valid.
ParseInt(ParseIntError)
Tried to parse an integer that was not an integer.
Server(TokenError)
An error returned by the server.
Tls(String)
An error in the TLS handshake.
Gssapi(String)
integrated-auth-gssapi only.An error from the GSSAPI library.
SspiRs(String)
sspi-rs only.An error from the sspi (sspi-rs) library.
Routing
Server requested a connection to an alternative address.
BulkInput(Cow<'static, str>)
Invalid input in Bulk Upload
Implementations