AltMetaDataColumn

Struct AltMetaDataColumn 

pub struct AltMetaDataColumn<'a> {
    pub op: u8,
    pub operand: u16,
    pub base: BaseMetaDataColumn,
    pub col_name: Cow<'a, str>,
}
A column produced by a COMPUTE clause, as described by an TokenAltMetaData (ALTMETADATA, token 0x88) stream.

In addition to the regular column metadata, each computed column carries the aggregate operator (op) that produced it (for example SUM, AVG, COUNT) and the operand column number (operand) the operator was applied to. See MS-TDS section 2.2.7.1.

Fields

op: u8

The aggregate operator that produced this column (Op in [MS-TDS]).

operand: u16

The column number in the originating result set that the aggregate operator was applied to (Operand in [MS-TDS]).

base: BaseMetaDataColumn

The regular column metadata (flags, type information).

col_name: Cow<'a, str>

The name of the computed column.