BulkLoadDirectPacketWriteStats

Struct BulkLoadDirectPacketWriteStats 

pub struct BulkLoadDirectPacketWriteStats {
Show 39 fields pub calls: u64, pub payload_bytes: u64, pub header_bytes: u64, pub max_payload_bytes: usize, pub final_calls: u64, pub final_payload_bytes: u64, pub final_header_bytes: u64, pub raw_stream_calls: u64, pub tls_stream_calls: u64, pub write_calls: u64, pub write_bytes: u64, pub max_write_bytes: usize, pub write_elapsed: Duration, pub max_write_elapsed: Duration, pub header_write_calls: u64, pub header_write_bytes: u64, pub header_max_write_bytes: usize, pub header_write_elapsed: Duration, pub header_max_write_elapsed: Duration, pub header_partial_writes: u64, pub payload_write_calls: u64, pub payload_write_bytes: u64, pub payload_max_write_bytes: usize, pub payload_write_elapsed: Duration, pub payload_max_write_elapsed: Duration, pub payload_partial_writes: u64, pub poll_write_polls: u64, pub poll_write_pending_count: u64, pub poll_write_pending_elapsed: Duration, pub poll_write_max_pending_elapsed: Duration, pub poll_write_ready_count: u64, pub poll_write_ready_elapsed: Duration, pub poll_write_max_ready_elapsed: Duration, pub flush_calls: u64, pub flush_elapsed: Duration, pub max_flush_elapsed: Duration, pub flush_pending_count: u64, pub flush_pending_elapsed: Duration, pub flush_max_pending_elapsed: Duration,
}
Available on crate feature bulk-load-profile only.
Detailed timing statistics for an experimental raw-bulk direct packet writer.

These counters are intended to compare an experimental bulk-only packet writer against the framed sink path. They remain zero when the framed path is used.

Fields

calls: u64

Number of TDS packets passed to the direct packet writer.

payload_bytes: u64

Payload bytes passed to the direct packet writer, excluding headers.

header_bytes: u64

Header bytes written by the direct packet writer.

max_payload_bytes: usize

Largest payload passed to the direct packet writer.

final_calls: u64

Number of final EndOfMessage packets passed to the direct packet writer.

final_payload_bytes: u64

Payload bytes in final EndOfMessage packets.

final_header_bytes: u64

Header bytes in final EndOfMessage packets.

raw_stream_calls: u64

Direct packet writes observed on a raw, non-TLS stream.

tls_stream_calls: u64

Direct packet writes observed on a TLS stream.

write_calls: u64

Number of lower-level write calls issued by the direct packet writer.

write_bytes: u64

Bytes accepted by lower-level writes, including headers and payloads.

max_write_bytes: usize

Largest byte count accepted by a single lower-level write.

write_elapsed: Duration

Time spent awaiting lower-level writes.

max_write_elapsed: Duration

Slowest lower-level write.

header_write_calls: u64

Number of lower-level writes used for packet headers.

header_write_bytes: u64

Header bytes accepted by lower-level writes.

header_max_write_bytes: usize

Largest header byte count accepted by a single lower-level write.

header_write_elapsed: Duration

Time spent awaiting lower-level header writes.

header_max_write_elapsed: Duration

Slowest lower-level header write.

header_partial_writes: u64

Header writes that accepted fewer bytes than remained in the header slice.

payload_write_calls: u64

Number of lower-level writes used for packet payloads.

payload_write_bytes: u64

Payload bytes accepted by lower-level writes.

payload_max_write_bytes: usize

Largest payload byte count accepted by a single lower-level write.

payload_write_elapsed: Duration

Time spent awaiting lower-level payload writes.

payload_max_write_elapsed: Duration

Slowest lower-level payload write.

payload_partial_writes: u64

Payload writes that accepted fewer bytes than remained in the payload slice.

poll_write_polls: u64

Number of low-level poll_write attempts.

poll_write_pending_count: u64

Number of poll_write attempts that returned Pending.

poll_write_pending_elapsed: Duration

Time spent waiting after poll_write returned Pending.

poll_write_max_pending_elapsed: Duration

Slowest wait after a poll_write returned Pending.

poll_write_ready_count: u64

Number of poll_write attempts that returned ready with a write result.

poll_write_ready_elapsed: Duration

Time spent in ready poll_write attempts.

poll_write_max_ready_elapsed: Duration

Slowest ready poll_write attempt.

flush_calls: u64

Number of explicit direct packet writer flushes.

flush_elapsed: Duration

Time spent awaiting explicit direct packet writer flushes.

max_flush_elapsed: Duration

Slowest explicit direct packet writer flush.

flush_pending_count: u64

Number of direct packet flush polls that returned Pending.

flush_pending_elapsed: Duration

Time spent waiting after direct packet flush polls returned Pending.

flush_max_pending_elapsed: Duration

Slowest wait after a direct packet flush poll returned Pending.