CommandResult

Struct CommandResult 

pub struct CommandResult { /* private fields */ }
A materialized result from executing a Command, carrying the number of affected rows, the return code, the values of any OUT parameters and any record sets returned by the command.

Example

let mut cmd = Command::new("dbo.usp_SomeStoredProc");

cmd.bind_param("@foo", 34i32);
cmd.bind_out_param("@bar", "bar");
let res = cmd.exec(&mut client).await?.into_command_result().await?;

let rv: Option<&str> = res.try_return_value("@bar")?;
let rc = res.return_code();
let ra = res.rows_affected();

let rs0 = res.to_query_result(0);

Implementations

Source

impl<'a> CommandResult

pub fn rows_affected(&self) -> &[u64]

A slice of the numbers of rows affected, in the same order as the statements ran by the command.

pub fn return_code(&self) -> u32

The return code of the command, as returned by the server.

pub fn return_values_len(&self) -> usize

The number of returned values (OUT parameters) available.

pub fn try_return_value<T>(&'a self, name: &str) -> Result<Option<T>>
where T: FromSql<'a>,

Gets a returned value by its OUT parameter name, converting it to T. Returns None if the value is NULL, and an error if no OUT parameter with the given name was returned.

pub fn to_query_result(&self, idx: usize) -> Option<&Vec<Row>>

Gets a returned record set by its zero-based index. Returns None if the index is out of range.