IntoRow

Trait IntoRow 

pub trait IntoRow<'a> {
    // Required method
    fn into_row(self) -> TokenRow<'a>;
}
create a TokenRow from list of values

Required Methods

fn into_row(self) -> TokenRow<'a>

create a TokenRow from list of values which implements IntoSQL

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, A, B, C, D, E, F, G, H, I, J> IntoRow<'a> for (A, B, C, D, E, F, G, H, I, J)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>, F: IntoSql<'a>, G: IntoSql<'a>, H: IntoSql<'a>, I: IntoSql<'a>, J: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D, E, F, G, H, I> IntoRow<'a> for (A, B, C, D, E, F, G, H, I)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>, F: IntoSql<'a>, G: IntoSql<'a>, H: IntoSql<'a>, I: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D, E, F, G, H> IntoRow<'a> for (A, B, C, D, E, F, G, H)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>, F: IntoSql<'a>, G: IntoSql<'a>, H: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D, E, F, G> IntoRow<'a> for (A, B, C, D, E, F, G)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>, F: IntoSql<'a>, G: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D, E, F> IntoRow<'a> for (A, B, C, D, E, F)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>, F: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D, E> IntoRow<'a> for (A, B, C, D, E)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>, E: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C, D> IntoRow<'a> for (A, B, C, D)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>, D: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B, C> IntoRow<'a> for (A, B, C)
where A: IntoSql<'a>, B: IntoSql<'a>, C: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Source

impl<'a, A, B> IntoRow<'a> for (A, B)
where A: IntoSql<'a>, B: IntoSql<'a>,

Source

fn into_row(self) -> TokenRow<'a>

Implementors

Source

impl<'a, A> IntoRow<'a> for A
where A: IntoSql<'a>,