TableValue

Trait TableValue 

pub trait TableValue<'a> {
    // Required method
    fn into_sql(self) -> SqlTableData<'a>;
}
A collection of TableValueRow values that can be bound as a table-valued parameter. Implemented for any IntoIterator of rows.

Required Methods

fn into_sql(self) -> SqlTableData<'a>

Converts this collection into the internal table data representation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, R, C> TableValue<'a> for C
where R: TableValueRow<'a> + 'a, C: IntoIterator<Item = R>,