TableValueRow

Trait TableValueRow 

pub trait TableValueRow<'a> {
    // Required methods
    fn bind_fields(&self, data_row: &mut SqlTableDataRow<'a>);
    fn get_db_type() -> &'static str;
}
A structure that represents a single row of a table-valued parameter (TVP) implements this trait.

It can be derived with #[derive(TableValueRow)] for structs with named fields.

Required Methods

fn bind_fields(&self, data_row: &mut SqlTableDataRow<'a>)

Binds this row’s field values. Called by Command before making the call to the server; implementations must call SqlTableDataRow::add_field once per column, in column order.

fn get_db_type() -> &'static str

The database type name that represents this TVP, e.g. dbo.MyType.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors