pub enum TypeInfo {
FixedLen(FixedLenType),
VarLenSized(VarLenContext),
VarLenSizedPrecision {
ty: VarLenType,
size: usize,
precision: u8,
scale: u8,
},
Xml {
schema: Option<Arc<XmlSchema>>,
size: usize,
},
Udt(UdtInfo),
}Expand description
Describes a type of a column.
Variants
FixedLen(FixedLenType)
A fixed-length type, whose size is fully determined by the type itself.
VarLenSized(VarLenContext)
A variable-length type with an explicit size (and optional collation).
VarLenSizedPrecision
A variable-length type carrying a precision and scale, such as decimal
and numeric.
Fields

ty: VarLenTypeThe underlying variable-length type.
Xml
The xml type, with an optional associated schema.
Fields
Udt(UdtInfo)
A CLR user-defined type (UDT), MS-TDS 2.2.5.5.4.