BulkLoadRequest

Struct BulkLoadRequest 

pub struct BulkLoadRequest<'a, S>
where S: AsyncRead + AsyncWrite + Unpin + Send,
{ /* private fields */ }
A handler for a bulk insert data flow.

Implementations

Source

impl<'a, S> BulkLoadRequest<'a, S>
where S: AsyncRead + AsyncWrite + Unpin + Send,

pub async fn send(&mut self, row: TokenRow<'a>) -> Result<()>

Adds a new row to the bulk insert, flushing only when having a full packet of data.

Warning

After the last row, finalize must be called to flush the buffered data and for the data to actually be available in the table.

pub async fn finalize(self) -> Result<ExecuteResult>

Ends the bulk load, flushing all pending data to the wire.

This method must be called after sending all the data to flush all pending data and to get the server actually to store the rows to the table.