pub trait RowTestExt {
// Required methods
fn build(
columns: impl IntoIterator<Item = (Column, ColumnData<'static>)>,
) -> Self;
fn with_result_index(&mut self, index: usize);
}Expand description
An extension trait for Row that provides test helpers.
Required Methods
Sourcefn build(
columns: impl IntoIterator<Item = (Column, ColumnData<'static>)>,
) -> Self
fn build( columns: impl IntoIterator<Item = (Column, ColumnData<'static>)>, ) -> Self
Create a new Row from the provided set of Columns and ColumnData.
Note: The Column and ColumnData pair are not checked, it’s up to the caller to make
sure the pairing is valid.
Sourcefn with_result_index(&mut self, index: usize)
fn with_result_index(&mut self, index: usize)
Sets the result index for this Row.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".